import { world, system } from '@minecraft/server';
system.beforeEvents.watchdogTerminate.subscribe((data) => {
    data.cancel = true;
});

world.beforeEvents.worldInitialize.subscribe((data) => {
    try {
        const l = world.getDynamicProperty('banlist')
        if (!l) {
            world.setDynamicProperty('banlist', JSON.stringify({}));
        }
    } catch (error) {
        console.warn(`Error in worldInitialize[beforeIvents]: ${error}`);
    }
});

world.afterEvents.playerSpawn.subscribe((data) => {
    system.runTimeout(() => {
        const players = world.getPlayers();
        const bl = JSON.parse(world.getDynamicProperty('banlist'))
        if (
            bl[data.player.name] === data.player.name ||
            bl[data.player.name] === data.player.id
        ) {
            if (
                data.player.hasTag('owner')) return;
            system.run(() => {
                data.player.runCommandAsync(`kick "${data.player.name}" §aBANLISIN!`)
            })
            return;
        }

        if (players.some(player => (player.hasTag('admin') && player.hasTag('unban')))) return;
        if (data.player.hasTag('ban')) {
            if (
                data.player.hasTag('owner')) return;
            runCmd(`kick "${data.player.name}" §aBANLISIN!`)
            return;
        }

    }, 10)
});

world.beforeEvents.chatSend.subscribe(msg => {
    if (msg.sender.hasTag('ban')) {
        if (msg.sender.hasTag('owner')) return;
        msg.cancel = true;
        runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§b[Sistem] §cSöhbeti kullanmak için izin yok!§r" }]}`);
        return;
    }
    if (msg.sender.hasTag("mute")) {
        if (msg.sender.hasTag('owner')) return;
        msg.cancel = true;
        runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§b[Sistem] §cSessize alındığın için Söhbette mesaj gönderemezsin!" }]}`);
        runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§b[Sistem] §cKişiye özel mesaj atabilmek için §b/msg ''Oyuncu_ismi'' ${msg.message} §cyazabilirsin!§r" }]}`);
    }
    if (msg.message.startsWith('.') || msg.message.startsWith('-')) {
        commands(msg.sender, msg.message, msg)
    }
});
function runCmd(cmd, d) {
    return world.getDimension(d || "overworld").runCommandAsync(cmd);
}
function helpInfo(msg) {
    runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§3*****************************" }]}`);
    runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§3*§2 -ban @<oyuncu ismi> - Oyuncuyu banlamak için!" }]}`);
    runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§3*§2 -unban @<oyuncu ismi> - Oyuncunun banını kaldırmak için!" }]}`);
    runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§3*§2 -mute @<oyuncu ismi> - Oyuncuyu sessize alamak için!" }]}`);
    runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§3*§2 -unmute @<oyuncu ismi> - Oyuncuyu sessizden çıkartmak için!" }]}`);
    runCmd(`tellraw "${msg.sender.name}" {"rawtext":[{"text": "§3*****************************" }]}`);
}

/**
 * 
 * @param {Object} sender - The player who sent the command.
 * @param {string} message - The message or command sent by the player.
 * @param {Object} msg - The chat message object containing details about the message.
 * 
 */
function commands(sender, message, msg) {
    if (message.slice(1).toLowerCase() === 'banlist') {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            const banlist = world.getDynamicProperty('banlist')
            if (banlist) {
                const bla = banlist.replace('{', '').replace('}', '').split(',')
                if (bla[0] !== '') {
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§bBan listesi:" }]}`);
                    bla.forEach(n => {
                        const result = n.replace(/"/gi, function (x) {
                            return '';
                        });
                        const id = result.split(':')
                        runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§3   İsim: §6${id[0]} §3Id: §6${id[1]}" }]}`);
                    });
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§bListede §7${bla.length}§b kişi var" }]}`);

                }
                else {
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §6Ban listesi boş!§r" }]}`);
                }
            }

        }
        else {
            runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§cKomutu kullanmak için önce yetkili olman ve '/tag @s add admin' yazman lazım!" }]}`);
        }
    } else if (message.slice(1).startsWith('ban')) {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            let username = message.slice(5).replace('@', '').replace('"', '').replace('"', '').trim();
            username = username.replace('@', '');
            if (username === '') {
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu ismini girin!§r" }]}`);
                return;
            }
            const player1 = world.getPlayers({ name: username })[0]
            if (player1) {
                let ll = JSON.parse(world.getDynamicProperty('banlist'));
                if (ll[player1.name]) {
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${player1.name}§7''§a önceden banlanmış zaten!§r" }]}`);
                    return;
                }
                ll[player1.name] = player1.id;
                system.run(() => {
                    sender.runCommandAsync(`kick "${player1.name}" BANLANDIN`)
                    world.setDynamicProperty('banlist', JSON.stringify(ll))
                    runCmd(`tellraw @a {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${player1.name}§7''§a §abanlandı!§r" }]}`);
                })
            } else {
                let ll = JSON.parse(world.getDynamicProperty('banlist'));
                if (ll[username]) {
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${username}§7''§a önceden banlanmış zaten!!§r" }]}`);
                    return;
                }
                ll[username] = username;
                system.run(() => {
                    world.setDynamicProperty('banlist', JSON.stringify(ll))
                    runCmd(`tellraw @a {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${username}§7''§a sunucuda degil ama banlandı!§r" }]}`);
                })
            }
        }
        else {
            runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§cKomutu kullanmak için önce yetkili olman ve '/tag @s add admin' yazman lazım!" }]}`);
        }
    } else if (message.slice(1).startsWith('bann')) {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            let username = message.slice(6).replace('@', '').replace('"', '').replace('"', '').trim();
            username = username.replace('@', '');
            if (username === '') {
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu ismini girin!§r" }]}`);
                return;
            }
            const player1 = world.getPlayers({ name: username })[0]
            if (player1) {
                let ll = JSON.parse(world.getDynamicProperty('banlist'));
                if (ll[player1.name]) {
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${player1.name}§7''§a önceden banlanmış zaten!§r" }]}`);
                    return;
                }
                ll[player1.name] = player1.id;
                system.run(() => {
                    sender.runCommandAsync(`kick "${player1.name}" BANLANDIN`)
                    world.setDynamicProperty('banlist', JSON.stringify(ll))
                })
            } else {
                let ll = JSON.parse(world.getDynamicProperty('banlist'));
                if (ll[username]) {
                    runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${username}§7''§a önceden banlanmış zaten!!§r" }]}`);
                    return;
                }
                ll[username] = username;
                system.run(() => {
                    world.setDynamicProperty('banlist', JSON.stringify(ll))
                })
            }
        }
        else {
            runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§cKomutu kullanmak için önce yetkili olman ve '/tag @s add admin' yazman lazım!" }]}`);
        }
    } else if (message.slice(1).startsWith('unban')) {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            let username = message.slice(7).replace('@', '').replace('"', '').replace('"', '').trim();
            username = username.replace('@', '');
            if (username === '') {
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu ismini girin!§r" }]}`);
                return;
            }
            let ll = JSON.parse(world.getDynamicProperty('banlist'));
            if (ll[username]) {
                delete ll[username];
                world.setDynamicProperty('banlist', JSON.stringify(ll));
                world.sendMessage(`§b[Sistem] §aOyuncu §7''§6${username}§7''§abani acildi!§r`);
                return;
            } else {
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${username}§7''§gban listesinde bulunamadı! §eİsmi doğru yazdığına emin ol!§r" }]}`);
            }
        }
        else {
            runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§cKomutu kullanmak için önce yetkili olman ve '/tag @s add admin' yazman lazım!" }]}`);
        }
    } else if (message.slice(1).startsWith('unbann')) {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            let username = message.slice(8).replace('@', '').replace('"', '').replace('"', '').trim();
            username = username.replace('@', '');
            if (username === '') {
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu ismini girin!§r" }]}`);
                return;
            }
            let ll = JSON.parse(world.getDynamicProperty('banlist'));
            if (ll[username]) {
                delete ll[username];
                world.setDynamicProperty('banlist', JSON.stringify(ll));
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${username}§7''§abani acildi!§r" }]}`);
                return;
            } else {
                runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §aOyuncu §7''§6${username}§7''§gban listesinde bulunamadı! §eİsmi doğru yazdığına emin ol!§r" }]}`);
            }
        }
        else {
            runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§cKomutu kullanmak için önce yetkili olman ve '/tag @s add admin' yazman lazım!" }]}`);
        }
    } else if (message.slice(1).toLowerCase().startsWith('mute')) {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            let username = message.slice(5).replace('@', '').replace('"', '').replace('"', '').trim();
            runCmd(`tag "${username}" add mute`)
            runCmd(`tellraw @a {"rawtext":[{"text": "§b[Sistem] §3§l${username} §r§3oyuncu sessize alındı§r" }]}`)
        } else {
            nCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §a§lGirdiğin komut hatalı, §eSunucudaki komutları öğrenmek için §6-?§e yazın!" }]}`);
        }
    } else if (message.slice(1).toLowerCase().startsWith('unmute')) {
        msg.cancel = true;
        if (sender.hasTag('admin')) {
            let username = message.slice(7).replace('@', '').replace('"', '').replace('"', '').trim();
            runCmd(`tag "${username}" remove mute`)
            runCmd(`tellraw @a {"rawtext":[{"text": "§b[Sistem] §3§l${username} §r§3oyuncu sessizden çıkartıldı§r" }]}`)
        } else {
            runCmd(`tellraw "${sender.name}" {"rawtext":[{"text": "§b[Sistem] §a§lGirdiğin komut hatalı, §eSunucudaki komutları öğrenmek için §6-?§e yazın!" }]}`);
        }
    } else if (message.slice(1).toLowerCase().startsWith('?')) {
        msg.cancel = true;
        helpInfo(msg);
    }
}
